@@ -7,7 +7,7 @@ use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(spawn receive msg snd quit wt snd_wt listener open_node);
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 use Carp;
 use IO::Select;
@@ -29,6 +29,7 @@ my %fh2fh            = ();
 my $self_vpid        = 0;
 my $self_parent_fh;
 my $self_parent_vpid = 0;
+my $self_parent_closed = 0;
 my %listener         = ();
 my %node             = ();
 my %snd              = ();
@@ -279,7 +280,11 @@ sub ipc_loop(;$$) {
 						next;
 					} else {
 						if ($self_parent_fh) {
-							$fh = $self_parent_fh;
+							unless ($self_parent_closed) {
+								$fh = $self_parent_fh;
+							} else {
+								next;
+							}
 						} else {
 							carp "The addressee $to is unknown or has left in $self_vpid (\$\$=$$)\n";
 							next;
@@ -379,7 +384,6 @@ sub ipc_loop(;$$) {
  				delete $r_bufs{$fh};
  				delete $w_bufs{$fh};
 				delete $fh2fh{$fh};
-				delete $snd{$fh};
 				delete $pack{$fh};
 				delete $unpack{$fh};
 				if (my $node_vpid = $node{$fh}) {
@@ -395,6 +399,7 @@ sub ipc_loop(;$$) {
 				delete $closed{$vpid};
  				close $fh;
 				if ($self_parent_fh and $self_parent_fh eq $fh) {
+					$self_parent_closed = 1;
 					unless (defined $waited_vpid and defined $waited_msg) {
 						unless (@rcv) {
 							exit;
