@@ -7,7 +7,7 @@ use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(spawn receive msg snd quit wt snd_wt listener open_node);
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 use Carp;
 use EV;
@@ -27,6 +27,7 @@ my %fh2fh            = ();
 my $self_vpid        = 0;
 my $self_parent_fh;
 my $self_parent_vpid = 0;
+my $self_parent_closed = 0;
 my %listener         = ();
 my %node             = ();
 my %snd              = ();
@@ -300,7 +301,11 @@ sub w_event_cb_reg {
 						next;
 					} else {
 						if ($self_parent_fh) {
-							$fh = $self_parent_fh;
+							unless ($self_parent_closed) {
+								$fh = $self_parent_fh;
+							} else {
+								next;
+							}
 						} else {
 							carp "The addressee $to is unknown or has left in $self_vpid (\$\$=$$)\n";
 							next;
@@ -390,7 +395,6 @@ sub r_event_cb {
  				delete $r_bufs{$fh};
  				delete $w_bufs{$fh};
 				delete $fh2fh{$fh};
-				delete $snd{$fh};
 				delete $pack{$fh};
 				delete $unpack{$fh};
 				if (my $node_vpid = $node{$fh}) {
@@ -408,6 +412,7 @@ sub r_event_cb {
 				delete $closed{$vpid};
  				close $fh;
 				if ($self_parent_fh and $self_parent_fh eq $fh) {
+					$self_parent_closed = 1;
 					unless (defined $waited_vpid and defined $waited_msg) {
 						unless (@rcv) {
 							exit;
